ChatVariableListResult class

Result of listing chat variables.

Constructors

ChatVariableListResult({required List<ChatVariable> variables, String? activeQuestId})
ChatVariableListResult.fromJson(Map<String, dynamic> json)
factory

Properties

activeQuestId String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variables List<ChatVariable>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited