ConversationConfig class

Bot conversation configuration (resolved from send_to_chat.json).

Constructors

ConversationConfig({required int maxTurns, required double temperature, required HistoryMode historyMode, required int maxHistoryTokens, String? modelConfig, required bool pauseBetweenTurns, required bool pauseBeforeFirst, required bool logConversation, required bool stripThinkingTags, String? copilotModel, required String conversationLogPath, required String goalReachedMarker, required List<String> profileKeys})
ConversationConfig.fromJson(Map<String, dynamic> json)
factory

Properties

conversationLogPath String
final
copilotModel String?
final
goalReachedMarker String
final
hashCode int
The hash code for this object.
no setterinherited
historyMode HistoryMode
final
logConversation bool
final
maxHistoryTokens int
final
maxTurns int
final
modelConfig String?
final
pauseBeforeFirst bool
final
pauseBetweenTurns bool
final
profileKeys List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stripThinkingTags bool
final
temperature double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited