FollowUpInput class

Input for adding a follow-up prompt to a queue item.

Constructors

FollowUpInput({required String promptText, String? template, bool? reminderEnabled, String? reminderTemplateId, int? reminderTimeoutMinutes, bool? reminderRepeat})

Properties

hashCode int
The hash code for this object.
no setterinherited
promptText String
final
reminderEnabled bool?
final
reminderRepeat bool?
final
reminderTemplateId String?
final
reminderTimeoutMinutes int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
template String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited