LanguageModelChat class

Represents a language model for chat requests

Constructors

LanguageModelChat({required String id, required String vendor, required String family, required String version, required String name, required int maxInputTokens})
LanguageModelChat.fromJson(Map<String, dynamic> json)
factory

Properties

family String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
maxInputTokens int
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vendor String
final
version String
final

Methods

countTokens(VSCodeAdapter adapter, String text, {int timeoutSeconds = 120}) Future<int>
Count tokens in text
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendRequest(VSCodeAdapter adapter, List<LanguageModelChatMessage> messages, {Map<String, dynamic>? modelOptions, int timeoutSeconds = 300}) Future<LanguageModelChatResponse>
Send a chat request to this model
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited