PermissionBehavior enum

Behaviour applied by a permission rule. Mirrors PermissionBehavior.

Inheritance
Available extensions

Values

allow → const PermissionBehavior

Allow the matched tool calls.

const PermissionBehavior('allow')
deny → const PermissionBehavior

Deny the matched tool calls.

const PermissionBehavior('deny')
ask → const PermissionBehavior

Ask the user.

const PermissionBehavior('ask')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wire String
The SDK wire string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWire(String value) PermissionBehavior
Parses an SDK wire string into a PermissionBehavior.

Constants

values → const List<PermissionBehavior>
A constant List of the values in this enum, in order of their declaration.