PermissionUpdate class sealed

A permission-rule mutation. Mirrors PermissionUpdate (six variants).

Implementers

Constructors

PermissionUpdate.fromJson(Map<String, dynamic> json)
Parses json into the matching PermissionUpdate variant.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The update type discriminator.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes to wire JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited