PermissionUpdateDestination enum

Where a permission update is persisted. Mirrors PermissionUpdateDestination.

Inheritance
Available extensions

Values

userSettings → const PermissionUpdateDestination

User-level settings.

const PermissionUpdateDestination('userSettings')
projectSettings → const PermissionUpdateDestination

Project-level settings.

const PermissionUpdateDestination('projectSettings')
localSettings → const PermissionUpdateDestination

Local (gitignored) settings.

const PermissionUpdateDestination('localSettings')
session → const PermissionUpdateDestination

This session only.

const PermissionUpdateDestination('session')
cliArg → const PermissionUpdateDestination

A CLI argument for this invocation.

const PermissionUpdateDestination('cliArg')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wire String
The SDK wire string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWire(String value) PermissionUpdateDestination
Parses an SDK wire string into a PermissionUpdateDestination.

Constants

values → const List<PermissionUpdateDestination>
A constant List of the values in this enum, in order of their declaration.