Position class

Position in a text document

Constructors

Position(int line, int character)
Position.fromJson(Map<String, dynamic> json)
factory

Properties

character int
final
hashCode int
The hash code for this object.
no setterinherited
line int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited