ProjectListResult class

Result of listing projects.

Constructors

ProjectListResult({required List<ProjectInfo> projects, required int totalCount})
ProjectListResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
projects List<ProjectInfo>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited