SystemPrompt class sealed

The system prompt. Mirrors string | string[] | { type:'preset', … }.

Implementers

Constructors

SystemPrompt.fromWire(Object value)
Parses an SDK wire value into a SystemPrompt.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Object
Serializes to the SDK wire value (a string, list, or map).

Operators

operator ==(Object other) bool
The equality operator.
inherited