TextEditor class

Text editor representation

Constructors

TextEditor({required TextDocument document, required Selection selection, required List<Selection> selections, Range? visibleRanges})
TextEditor.fromJson(Map<String, dynamic> json)
factory

Properties

document TextDocument
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection Selection
final
selections List<Selection>
final
visibleRanges Range?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited