ThinkingConfig class sealed

Extended-thinking configuration. Mirrors ThinkingConfig.

Implementers

Constructors

ThinkingConfig.fromWire(Map<String, dynamic> value)
Parses an SDK wire map into a ThinkingConfig.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Map<String, dynamic>
Serializes to the SDK wire map.

Operators

operator ==(Object other) bool
The equality operator.
inherited