ThinkingEnabled class final
Fixed thinking budget (type: 'enabled').
- Inheritance
-
- Object
- ThinkingConfig
- ThinkingEnabled
Constructors
- ThinkingEnabled({int? budgetTokens, String? display})
-
const
Properties
- budgetTokens → int?
-
The thinking token budget.
final
- display → String?
-
How thinking is displayed (
summarized|omitted).final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toWire(
) → Map< String, dynamic> -
Serializes to the SDK wire map.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited