TodoScope class

Scope within a todo item.

Constructors

TodoScope({String? project, List<String>? projects, String? module, String? area, List<String>? files})
TodoScope.fromJson(Map<String, dynamic> json)
factory

Properties

area String?
final
files List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
module String?
final
project String?
final
projects List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited