TrailListResult class

Result of listing trail entries.

Constructors

TrailListResult({required List<TrailEntry> entries, required int totalCount, String? questId})
TrailListResult.fromJson(Map<String, dynamic> json)
factory

Properties

entries List<TrailEntry>
final
hashCode int
The hash code for this object.
no setterinherited
questId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited