VSCodeBridgeResult class

Result of a VS Code bridge command execution.

Constructors

VSCodeBridgeResult({required bool success, dynamic value, String output = '', String? error, String? stackTrace, String? exception, String? exceptionStackTrace, required Duration duration})
const
VSCodeBridgeResult.failure({required String error, String? stackTrace, String output = '', required Duration duration})
Creates a failure result with optional logs and stack trace.
factory
VSCodeBridgeResult.success({dynamic value, String output = '', String? exception, String? exceptionStackTrace, required Duration duration})
Creates a successful result.
factory

Properties

duration Duration
Execution duration.
final
error String?
Error message (if failed).
final
exception String?
Exception message if one was caught internally during successful execution.
final
exceptionStackTrace String?
Exception stack trace if one was caught internally.
final
hasException bool
Whether an exception was caught internally during execution.
no setter
hashCode int
The hash code for this object.
no setterinherited
output String
Output from the execution (logs on error).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace String?
Stack trace (if failed).
final
success bool
Whether the execution was successful.
final
value → dynamic
The result value (if successful).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited