VSCodeCommands class

Wrapper for vscode.commands API Provides access to VS Code command system

Constructors

VSCodeCommands(VSCodeAdapter _adapter)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

executeCommand(String command, {List? args, int timeoutSeconds = 120}) Future
Execute a VS Code command Returns the result of the command execution (can be any type)
getCommands({bool filterInternal = false, int timeoutSeconds = 60}) Future<List<String>>
Get all registered commands
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerCommand(String command, String handlerScript, {int timeoutSeconds = 120}) Future<bool>
Register a command (requires command to be defined on TypeScript side) This is a helper that creates a command registration on the TS side Returns true if successful
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited