VSCodeLanguageModel class

Language Model API - Access to GitHub Copilot and other language models

Constructors

VSCodeLanguageModel(VSCodeAdapter _adapter)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTools({int timeoutSeconds = 60}) Future<List<LanguageModelToolInformation>>
Get list of available tools
invokeTool(String name, Map<String, dynamic> options, {int timeoutSeconds = 300}) Future<LanguageModelToolResult>
Invoke a registered tool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerTool(String name, Map<String, dynamic> tool, {int timeoutSeconds = 120}) Future<void>
Register a language model tool
selectChatModels({String? vendor, String? family, String? id, String? version, int timeoutSeconds = 60}) Future<List<LanguageModelChat>>
Select chat models matching the given criteria
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited