WorkspaceInfo class

Workspace metadata.

Constructors

WorkspaceInfo({required String name, required String rootPath, String? workspaceFile, required int projectCount, required int questCount, String? activeQuestId, String? windowId, Map<String, dynamic>? metadata})
WorkspaceInfo.fromJson(Map<String, dynamic> json)
factory

Properties

activeQuestId String?
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
final
name String
final
projectCount int
final
questCount int
final
rootPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
windowId String?
final
workspaceFile String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited