AgentSdkToolRegistry class
Indexes the Dart ToolHandlers a query exposes and dispatches incoming
agentSdk.toolCall requests to them.
Constructors
Properties
- hasHandlers → bool
-
Whether any tool handlers are registered.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addServers(
Map< String, McpServerConfig> ? mcpServers) → bool -
Registers the handlers carried by
mcpServers's McpSdkServerConfig entries. Non-sdk servers and handler-less (descriptor-only) tools are ignored. Returnstrueif at least one handler was registered. -
handleToolCall(
Map< String, dynamic> params) → Future<Map< String, dynamic> > -
Dispatches an
agentSdk.toolCallrequest to the matching handler. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited