SdkAssistantMessage class final
Mirrors SDKAssistantMessage (type: 'assistant').
- Inheritance
-
- Object
- SdkMessage
- SdkAssistantMessage
Constructors
-
SdkAssistantMessage(Map<
String, dynamic> raw)
Properties
-
content
→ List<
ContentBlock> -
The assistant content blocks (
message.content).no setter - error → String?
-
Optional error discriminator (
SDKAssistantMessageError).no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
message
→ Map<
String, dynamic> ? -
The underlying Anthropic message object.
no setter
- parentToolUseId → String?
-
Id of the parent tool use, if this assistant turn is a sub-agent reply.
no setter
-
raw
→ Map<
String, dynamic> -
The full original wire JSON for this message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
The session id the message belongs to (
session_id).no setterinherited - type → String
-
The SDK
typediscriminator (assistant,user,result, …).no setterinherited - uuid → String?
-
The message's unique id (
uuid).no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Reproduces the original wire JSON verbatim.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited