TimedRequestInput class
Input for creating a new timed request.
Constructors
-
TimedRequestInput({required String promptText, String? template, bool? answerWrapper, required ScheduleMode scheduleMode, int? intervalMinutes, List<
ScheduledTime> ? scheduledTimes, bool? reminderEnabled, String? reminderTemplateId, int? reminderTimeoutMinutes, bool? reminderRepeat})
Properties
- answerWrapper → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- intervalMinutes → int?
-
final
- promptText → String
-
final
- reminderEnabled → bool?
-
final
- reminderRepeat → bool?
-
final
- reminderTemplateId → String?
-
final
- reminderTimeoutMinutes → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scheduledTimes
→ List<
ScheduledTime> ? -
final
- scheduleMode → ScheduleMode
-
final
- template → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited