TimedRequestListResult class
Result of listing timed requests.
Constructors
-
TimedRequestListResult({required List<
TimedRequest> entries, required int totalCount, required int activeCount, required int pausedCount, required bool timerActivated}) -
TimedRequestListResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activeCount → int
-
final
-
entries
→ List<
TimedRequest> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pausedCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timerActivated → bool
-
final
- totalCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited