ToolUseBlock class final
Mirrors a tool_use content block.
- Inheritance
-
- Object
- ContentBlock
- ToolUseBlock
Constructors
-
ToolUseBlock(Map<
String, dynamic> raw)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The tool-use id.
no setter
-
input
→ Map<
String, dynamic> -
The tool input arguments.
no setter
- name → String
-
The invoked tool name.
no setter
-
raw
→ Map<
String, dynamic> -
The full original wire JSON for this block.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The block
typediscriminator.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Reproduces the original wire JSON verbatim.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited